is_gba

Function is_gba 

pub fn is_gba() -> bool
Whether the machine is a Game Boy Advance running a Game Boy Color cartridge.

Programs usually ask in order to lighten their palettes, the Advance’s screen being the darker of the two.